@@ -56,7 +56,8 @@ class Packager(object):
                     print "Version: %s" % version
                     print "Saving: %s" % self.compressor.relative_path(output_filename)
                 paths = self.compile(package['paths'])
-                content = compress(paths, **kwargs)
+                content = compress(paths,
+                    asset_url=self.individual_url(output_filename), **kwargs)
                 self.save_file(output_filename, content)
                 signal.send(sender=self, package=package, version=version)
         else:
